amulet package
==============

amulet.deployer module
----------------------

.. automodule:: amulet.deployer
    :members: Deployment
    :undoc-members:
    :special-members: __init__

amulet.sentry module
--------------------

.. automodule:: amulet.sentry
    :members: Talisman, UnitSentry
    :special-members: __getitem__
    :private-members:
    :show-inheritance:
